#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-logger
version:              2.3.6
visibility:           public
id:                   wai-logger-2.3.6-D38BZlKnHPTKsiCW915NQw
key:                  wai-logger-2.3.6-D38BZlKnHPTKsiCW915NQw
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             A logging system for WAI
description:          A logging system for WAI
category:             Web, Yesod
abi:                  0b5116680141b459b98c20b04a23b338
exposed:              True
exposed-modules:      Network.Wai.Logger
hidden-modules:
    Network.Wai.Logger.Apache Network.Wai.Logger.IP
    Network.Wai.Logger.IORef

import-dirs:          /usr/lib/ghc-8.10.5/site-local/wai-logger-2.3.6
library-dirs:         /usr/lib/ghc-8.10.5/site-local/wai-logger-2.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/wai-logger-2.3.6
hs-libraries:         HSwai-logger-2.3.6-D38BZlKnHPTKsiCW915NQw
depends:
    base-4.14.2.0 byteorder-1.0.4-HnaHkJFNp8iDlUJGtdnY0n
    bytestring-0.10.12.0 fast-logger-3.0.5-I5dfCGxOK271HLzqt5yeow
    http-types-0.12.3-JSCBEGU6f6MIPS3hXwEPIB
    network-3.1.2.2-5EE9GqQpTmvH0oBl8byO4M
    wai-3.2.3-6NrdunSiuKK6vnccK2cwty

haddock-interfaces:   /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html:         /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

